import { WbkMessageType, BaseMessage } from "./MessageApi";
import { CustomCatalogArticle, CustomArticle, WbkConfiguration } from "./WbkParameters";

/** Base interface for wbk messages. */
export interface WbkMessage extends BaseMessage
{
    type: WbkMessageType;
}

/**
 * After a `wbkHost.getConfiguration` message was received, this message has to be send to the basket.
 */
export interface WbkConfigurationMessage extends WbkMessage
{
    type: "wbk.configuration";
    parameter: WbkConfiguration;
}

/**
 * Should be used to send a new pCon.login access token to the basket before the old one expires.
 * Has to contain the new access token as parmater.
 */
export interface WbkUpdateUserAccessTokenMessage extends WbkMessage
{
    type: "wbk.updateUserAccessToken";
    parameter: string;
}

/**
 * After a `wbkHost.getCustomArticle` message was received, this message has to be send to the basket.
 */
export interface WbkCustomArticleMessage extends WbkMessage
{
    type: "wbk.customArticle";
    parameter: CustomArticle;
}

/**
 * After a `wbkHost.getCustomCatalogArticles` message was received, this message has to be send to the basket.
 */
export interface WbkCustomCatalogArticlesMessage extends WbkMessage
{
    type: "wbk.customCatalogArticles";
    parameter: Array<CustomCatalogArticle>;
}

/** Can be send to change the project title. Has to contain the new title as parmater. */
export interface WbkSetProjectTitleMessage extends WbkMessage
{
    type: "wbk.setProjectTitle";
    parameter: string;
}

/**
 * Has to be send to the basket after receiving the `wbkHost.saveProject` message and saving the project.
 */
export interface WbkSaveProjectDoneMessage extends WbkMessage
{
    type: "wbk.saveProjectDone";
}

/**
 * Can be used to request the current session modifications. A `wbkHost.sessionModifications`
 * message will be send to the host in response.
 * Note: Everytime the modifications will be requested the internal modifications state will be reset.
 */
export interface WbkGetSessionModificationsMessage extends WbkMessage
{
    type: "wbk.getSessionModifications";
}

/**
 * Can be used to finish the integration programmatically (without using the "Done" button of the application).
 * After receiving the `wbk.finishIntegration` message, the basket will finish all pending tasks
 * and will send a `wbkHost.done` message back to the host afterwards.
 * The basket window can then savely be closed by the host.
 */
export interface WbkFinishIntegrationMessage extends WbkMessage
{
    type: "wbk.finishIntegration";
}