import { HostGetCustomArticleMessage, HostGetCustomCatalogArticlesMessage } from "../../libs/integration-api/HostMessages";
import { WbkCustomArticleMessage, WbkCustomCatalogArticlesMessage } from "../../libs/integration-api/WbkMessages";
import { CustomArticle, CustomCatalog, CustomCatalogArticle } from "../../libs/integration-api/WbkParameters";
import { Application } from "../Application";

/** Returns the configuration for the custom catalogs used for the `wbk.configuration` message. */
export function getCustomCatalogConfiguration(): Array<CustomCatalog>
{
    return [
        //register custom catalog
        {
            id: "exampleCustomCatalog",
            label: "My Custom Catalog",
            imageUrl: "https://integration.basket.pcon-solutions.com/example-data/custom-catalog/catalog-logo.jpg"
        },
        //register external catalog
        {
            id: "exampleExternalCatalog",
            label: "My External Catalog",
            imageUrl: "https://integration.basket.pcon-solutions.com/example-data/external-catalog/catalog-logo.jpg",
            externalUrl: "https://integration.basket.pcon-solutions.com/example-data/external-catalog/catalog.html"
        }
    ];
}

/**
 * Send example the data of the example custom catalog to the basket.
 */
export function handleCustomCatalogArticlesMessage(pApp: Application, pMessage: HostGetCustomCatalogArticlesMessage): void
{
    let tArticles: Array<CustomCatalogArticle> = [];
    const tQuery = pMessage.parameter;

    if (tQuery.catalogId == null || tQuery.catalogId === "exampleCustomCatalog") {
        if (tQuery.queryString == null || ("chair").indexOf(tQuery.queryString.toLowerCase()) === 0) {
            tArticles.push({
                id: "ch",
                label: "My Chair",
                articleNumber: "chair-1",
                manufacturerId: "XY",
                seriesId: "CH",
                catalogId: "exampleCustomCatalog",
                imageUrl: "https://integration.basket.pcon-solutions.com/example-data/custom-catalog/chair.jpg"
            });
        }
        if (tQuery.queryString == null || ("table").indexOf(tQuery.queryString.toLowerCase()) === 0) {
            tArticles.push({
                id: "ta",
                label: "My Table",
                articleNumber: "table-1",
                manufacturerId: "XY",
                seriesId: "TA",
                catalogId: "exampleCustomCatalog",
                imageUrl: "https://integration.basket.pcon-solutions.com/example-data/custom-catalog/table.jpg"
            });
        }
    }

    tArticles = tArticles.filter((article) =>
    {
        if (tQuery.seriesId != null && article.seriesId !== tQuery.seriesId)
            return (false);
        if (tQuery.baseArticleNumber != null && article.articleNumber !== tQuery.baseArticleNumber)
            return (false);
        return (true);
    });

    const tMessage: WbkCustomCatalogArticlesMessage = {
        type: "wbk.customCatalogArticles",
        parameter: tArticles
    };
    pApp.sendMessageToBasket(tMessage);
}

/**
 * Send example data of custom afticles to the basket.
 */
export function handleCustomArticleMessage(pApp: Application, pMessage: HostGetCustomArticleMessage): void
{
    let tArticle: CustomArticle | undefined;
    const tQuery = pMessage.parameter;

    if (tQuery.articleId === "ch") {
        tArticle = {
            baseArticleNumber: "chair-1",
            manufacturerId: "XY",
            seriesId: "CH",
            shortText: "My Chair",
            longText: "This is my chair.",
            quantity: 2, //insert two chairs
            imageUrl: "https://integration.basket.pcon-solutions.com/example-data/custom-catalog/chair.jpg",
            salesPrice: {
                value: 300,
                currency: "EUR"
            }
        };
    } else if (tQuery.articleId === "ta") {
        tArticle = {
            baseArticleNumber: "table-1",
            manufacturerId: "XY",
            seriesId: "TA",
            shortText: "My Table",
            longText: "This is my table.",
            imageUrl: "https://integration.basket.pcon-solutions.com/example-data/custom-catalog/table.jpg",
            salesPrice: {
                value: 500,
                currency: "EUR"
            }
        };
    }

    if (tArticle == null) {
        throw new Error("Unknown article");
    }

    const tMessage: WbkCustomArticleMessage = {
        type: "wbk.customArticle",
        parameter: tArticle
    };
    pApp.sendMessageToBasket(tMessage);
}