import { ProjectInfo } from "@easterngraphics/wcf/modules/bsk";
import { EaiwsSession } from "@easterngraphics/wcf/modules/eaiws";

import { MenuAction } from "../Action";
import { ProjectEditor, ProjectEditorOptions } from "../plugins/ProjectEditor";

/**
 * Options for `ComponentFactory.createProjectEditorActivity()`
 */
export interface ProjectEditorActivityOptions extends Omit<ProjectEditorOptions,
    "container" | "eaiwsSession" | "projectInfo">
{
    /** If true the project name will be used as the title for the activity. (default: true) */
    useProjectNameAsTitle?: boolean;

    /** If true the eaiws session will be closed if the activity gets disposed. (default: true) */
    closeSessionOnDispose?: boolean;

    /**
    * Can be used to create a custom eaiws session. If not implemented a default session will be created.
    * Null should be returned if the start of the project editor should be aborted.
    */
    onCreateSession?: () => Promise<EaiwsSession | null>;

    /**
    * Can be used to prepare the eaiws session before starting the project editor.
    * False should be returned if the start of the project editor should be aborted.
    * E.g. Can be used to load an existing project.
    */
    onPrepareSession?: (pSession: EaiwsSession) => Promise<boolean>;

    /**
    * Will be called before creating the project editor to define a pre-created `ProjectInfo` instance.
    */
    onGetProjectInfo?: (pSession: EaiwsSession) => ProjectInfo | null;

    /**
    * Will be called directly after the project editor was started.
    */
    onPrepareProjectEditor?: (pProjectEditor: ProjectEditor) => Promise<void>;

    /**
     * Will be called everytime the main menu gets opened.
     * Can be used to add new actions or override the project editor actions.
     * Note: use pProjectEditor.getMainMenuActions() to get the default actions of the editor.
     */
    onGetMainMenuActions?: (pProjectEditor: ProjectEditor | null) => ReadonlyArray<MenuAction> | null;

    /**
     * Can be implemented to make preparations before the activity gets stopped and disposed.
     * If `pCancelable` is true and the promise resolves with false, the activity stop will be canceled.
     * Otherwise true should be returned.
    */
    onPrepareActivityStop?: (pProjectEditor: ProjectEditor | null, pCancelable: boolean) => Promise<boolean>;
}