import { Plugin, PluginDescriptor } from "../Plugin";
import { UserRestriction } from "../types/User";

/**
 * Authorizes users for plugin access and retrieves user restrictions.
 * - Plugin category = `Authorization`
 */
export interface AuthorizationPlugin extends Plugin
{
    /**
     * Returns a set of restrictions for the current user. If null the
     * default restrictions of the application will be used.
     */
    getUserRestrictions(): Promise<ReadonlySet<UserRestriction> | null>;

    /**
     * Returns true if the current user is authorized to use the given plugin.
     * If false is returned the plugin will be unavailable for the user.
     */
    isPluginAuthorized(pDescriptor: PluginDescriptor): boolean;
}
