import { Property as CoreProperty } from "@easterngraphics/wcf/modules/core/prop";
import { Property as EaiwsProperty, ArticleData as EaiwsArticleData} from "@easterngraphics/wcf/modules/eaiws/basket";
import { Plugin } from "../Plugin";

/**
 * Available sub categories for `ItemConfigurationExtension` plugins
 */
export type ExtensionSubCategory = "PropertyFilter";

/**
 * Extension for the catalog which is used to filter the displayed catalog items.
 * - Plugin category = `ItemConfigurationExtension`
 * - Plugin sub category = `PropertyFilter`
 *
 * Note: For article properties `pUtils.getEaiwsPropertyData()` can be
 * used to retrieve the underlying `eaiws/basket/Property` and `eaiws/basket/ArticleData`.
 */
export interface PropertyFilterExtension extends Plugin
{
    filterProperties(pUtils: PropertyUtils, pProperties: ReadonlyArray<CoreProperty>): Array<CoreProperty>;
}

/**
 * Utils for property handling.
 */
export interface PropertyUtils
{
    /** Returns the EAIWS data for the given property if available. */
    getEaiwsPropertyData(pProperty: CoreProperty): EaiwsPropertyData | null;
}

/** Underlying EAIWS data of a property. */
export interface EaiwsPropertyData
{
    property: EaiwsProperty;
    articleData: EaiwsArticleData;
}
