import { ProjectInfo } from "@easterngraphics/wcf/modules/bsk";

import { Plugin } from "../Plugin";
import { PluginComponent } from "../PluginComponent";
import { UserRestriction } from "../types/User";
import { ProjectWorkflow } from "./ProjectWorkflow";

export interface ProjectDataOptions
{
    /** Owner of this component. */
    owner: PluginComponent;

    /** Html container for the ui. */
    container: HTMLElement;

    /** ProjectInfo which will be used from the ui. */
    projectInfo: ProjectInfo;

    /** Restrictions for the current user. If undefined the default restrictions of the application will be used. */
    userRestrictions?: ReadonlySet<UserRestriction>;

    /** Currently active project workflow. */
    workflow?: ProjectWorkflow;
}

/**
 * Plugin component created by the ProjectDataPlugin.
 */
export interface ProjectData extends PluginComponent
{
    /**
     * Can be used to alter the user restrictions of this component.
     */
    setUserRestrictions(pRestrictions: ReadonlySet<UserRestriction>): void;
}

/**
 * Plugin which is used to display and edit project information.
 * E.g.: Project Name, Project Number, Status etc.
 * - Plugin category = `ProjectData`
 */
export interface ProjectDataPlugin<T extends ProjectData = ProjectData, O extends ProjectDataOptions = ProjectDataOptions> extends Plugin
{
    createComponent(pOptions: O): Promise<T>;
}
