import { AsyncListenableEvent } from "@easterngraphics/wcf/modules/utils";
import { PluginComponent } from "../PluginComponent";
import { ProjectEditor } from "./ProjectEditor";
import { BaseComponentExtension } from "./ProjectEditorExtension";

export type TemplateOptionValue = boolean | string | number | undefined;

interface BaseGenerateReportEventData
{
    /** name/id of the used report template */
    template: string;
    /** active template options */
    templateOptions?: { [key: string]: TemplateOptionValue };
    /** id of the active basket view */
    basketViewId: string;
    /** project editor with the curretnt active project */
    projectEditor: ProjectEditor;
}

/** data for `ProjectReportPlugin.eventBeforeGenerateReport`  */
export interface BeforeGenerateReportEventData extends BaseGenerateReportEventData
{
}

/** data for `ProjectReportPlugin.eventAfterGenerateReport` */
export interface AfterGenerateReportEventData extends BaseGenerateReportEventData
{
    /** Name of the generated pdf. */
    pdfName: string;
    /** Url of the generated report. */
    pdfUrl: string;
}

export interface ProjectReport extends PluginComponent
{
}

/**
 * Plugin that creates the ProjectReport component and adds reporting functionality to the basket.
 * - Plugin category = `ProjectReport`
 */
export interface ProjectReportPlugin extends BaseComponentExtension<ProjectReport>
{
    /** Event which will be callled before a report is generated. */
    eventBeforeGenerateReport: AsyncListenableEvent<BeforeGenerateReportEventData, ProjectReportPlugin>;
    /** Event which will be callled after a report was generated. */
    eventAfterGenerateReport: AsyncListenableEvent<AfterGenerateReportEventData, ProjectReportPlugin>;
}