import { PluginDescriptor } from '../../plugin-sdk/wbk-core/Plugin';
import { PluginComponent } from '../../plugin-sdk/wbk-core/PluginComponent';
import { ItemPanelExtension } from '../../plugin-sdk/wbk-core/plugins/ProjectEditorExtension';
import { ProjectEditor } from '../../plugin-sdk/wbk-core/plugins/ProjectEditor';

import wbkApp = egr.wbkApp;


/** implementation of ItemPanelExtension plugin interface */
class PluginImpl implements ItemPanelExtension
{
    public get name(): string
    {
        return ("examplePlugin-itemPanel");
    }

    public async initialize(pDescriptor: PluginDescriptor, pSettings: unknown): Promise<void>
    {
    }

    public async createComponent(pEditor: ProjectEditor, pContainer: HTMLElement): Promise<PluginComponent>
    {
        //return new instance of our component implementation
        return (new Component(pEditor, pContainer));
    }
}


/**
 * implementation of PluginComponent interface
 * This example will show the first selected item inside the conainer.
 */
class Component implements PluginComponent
{
    public get isActive(): boolean
    {
        return (this.mIsActive);
    }


    public constructor(pEditor: ProjectEditor, pContainer: HTMLElement)
    {
        this.mEditor = pEditor;
        this.mContainer = pContainer;
        this.mIsActive = false;

        //register event listener to handle selection changes
        this.mEditor.basket.eventSelectionChanged.addListener(this.onSelectionChanged);
    }


    public async setActive(pActive: boolean): Promise<void>
    {
        this.mIsActive = pActive;
        this.updateLabel();
    }


    public async dispose(): Promise<void>
    {
        //remove register event listener
        this.mEditor.basket.eventSelectionChanged.removeListener(this.onSelectionChanged);
    }


    private onSelectionChanged = () =>
    {
        this.updateLabel();
    }


    private updateLabel(): void
    {
        if (!this.mIsActive)
            return;

        if (this.mEditor.basket.selection.length === 0) {
            this.mContainer.innerText = "empty selection";
        } else {
            this.mContainer.innerText = "selected item: " + this.mEditor.basket.selection[0].label;
        }
    }


    private mEditor: ProjectEditor;
    private mContainer: HTMLElement;
    private mIsActive: boolean;
}


//register plugin
wbkApp.pluginManager.registerPlugin(new PluginImpl());