import { Disposable } from "./types/Disposable";


export interface PluginComponent extends Disposable
{
    /**
     * Optional activity state of this component.
     * Initial component state should be inactive (false or undefined).
     */
    readonly isActive?: boolean;

    /**
     * Optional activity state handling for this component. E.g. can be used to disable/enable event handling.
     * Will be set from the component host to activate or deactivate the component.
     * Initial component state should be inactive (false or undefined).
     */
    setActive?(pActive: boolean): Promise<void>;
}


/**
 * OverlayPluginComponent is used for ui overays such as dialogs.
 * The isActive state of the component is used to control the visibility of the overlay.
 */
export interface OverlayPluginComponent extends PluginComponent
{
    /**
     * Optional callback which has to be called if the overlay gets dismissed (e.g. the dialog was closed).
     */
    onDismiss: (() => void) | undefined;
}