import { Plugin } from "../Plugin";
import { User } from "../types/User";

/**
 * Authentication interface used to identify the user.
 * Provides the login and logout lifecycle.
 * - Plugin category = `Authentication`
 */
export interface AuthenticationPlugin extends Plugin
{
    /** The currently logged in user. */
    readonly user: User | null;

    /** Optional settings storage which is used to store the user settings. */
    readonly userSettingsStorage?: UserSettingsStorage;

    /** If true the user may logout from the application. */
    readonly logoutSupported: boolean;

    login(): Promise<void>;
    logout(): Promise<void>;
}

export interface UserSettingsStorage
{
    /**
    * Sets or overrides the persisted value of a setting.
    * `undefined` can be used as value to delete the setting from the storage.
    */
    setSetting(pKey: string, pValue: string | undefined): Promise<void>;
    /**
     * Retrieves the persisted value of a setting. `undefined` will be returend if the setting
     * does not have a value yet.
     */
    getSetting(pKey: string): Promise<string | undefined>;
}
