import { BasketItem } from "@easterngraphics/wcf/modules/bsk";
import { ListenableEvent } from "@easterngraphics/wcf/modules/utils";

import { Plugin } from "../Plugin";
import { Disposable } from "../types/Disposable";
import { ProjectEditor } from "./ProjectEditor";


/**
 * Available sub categories for `ItemListExtension` plugins
 */
export type ExtensionSubCategory = "ItemDescriptionProvider";

/**
 * Interface to define an additional line for the item description.
 */
export interface ItemDescriptionLine
{
    /** Text for this description line. */
    text: string;
    /**
     * text color as hex color string e.g. `#FF0000`. If undefined a default collor will be used.
     */
    color?: string;
}

/**
 * Provides an additional description line for basket items.
 * - Plugin category = `ItemListExtension`
 * - Plugin sub category = `ItemDescriptionProvider`
 */
export interface ItemDescriptionProviderPlugin extends Plugin
{
    /**
     * Create a new instance of ItemDescriptionProvider.
     */
    createProvider(pEditor: ProjectEditor): Promise<ItemDescriptionProvider>;
}

export interface ItemDescriptionProvider extends Disposable
{
    /**
     * Will be triggered everytime the description of an item has changed (after it was fetched initially).
     */
    readonly eventItemDescriptionChanged: ListenableEvent<BasketItem, ItemDescriptionProvider>;

    /**
     * Fetches the descriptions for the given items. Afterwards `getItemDescription()` no longer
     * returns `undefined` for these items (except if the descriptions have changed).
     */
    fetchItemDescriptions(pItems: ReadonlyArray<BasketItem>): Promise<void>;

    /**
     * Returns the currently known description for the given item.
     * If the description is unknown (not fetched yet) `undefined` will be returned.
     * If the item does not have a description `null` will be returned.
     */
    getItemDescription(pItem: BasketItem): ItemDescriptionLine | null | undefined;
}