import { BasketItem } from "@easterngraphics/wcf/modules/bsk";
import { ListenableEvent } from "@easterngraphics/wcf/modules/utils";

import { Plugin } from "../Plugin";
import { Disposable } from "../types/Disposable";
import { ProjectEditor } from "./ProjectEditor";

export interface ItemStatusIcon
{
    /**
     * Defines the icon by name.
     */
    iconName?: string;

    /**
     * Icon color as hex color string e.g. `#FF0000`. If undefined a default collor will be used.
     */
    iconColor?: string;

    /**
     * Defines the icon by image url. If defined `iconName` and `iconColor` will be ignored and the image will be shown.
     */
    iconUrl?: string;

    /**
     * Tooltip text for the icon.
     */
    tooltip?: string;

    /**
     * Click handler for the icon.
     */
    onClick?: () => void;
}


/**
 * Provides a status icon for basket items.
 * - Plugin category = `ItemStatusProvider`
 */
export interface ItemStatusProviderPlugin extends Plugin
{
    /**
     * Create a new instance of ItemStatusProvider.
     */
    createProvider(pEditor: ProjectEditor): Promise<ItemStatusProvider>;
}


export interface ItemStatusProvider extends Disposable
{
    /**
     * Will be triggered everytime the status of an item has changed (after it was fetched initially).
     */
    readonly eventItemStatusChanged: ListenableEvent<BasketItem, ItemStatusProvider>;

    /**
     * Fetches the status for the given items. Afterwards `getItemStatusIcon()` no longer
     * returns `undefined` for these items (except if the status has changed).
     */
    fetchItemStatus(pItems: ReadonlyArray<BasketItem>): Promise<void>;

    /**
     * Returns the currently known status icon for the given item.
     * If the status is unknown (was not fetched yet) `undefined` will be returned.
     * If the item has no icon `null` will be returned.
     */
    getItemStatusIcon(pItem: BasketItem): ItemStatusIcon | null | undefined;
}