import { EaiwsSession } from "@easterngraphics/wcf/modules/eaiws";
import { Plugin } from "../Plugin";

export interface Manufacturer
{
    manufacturerId: string;
    manufacturerName: string;
    series?: Array<Series>;
}

export interface Series
{
    seriesId: string;
    seriesName: string;
}

export interface GetManufacturersOptions
{
    /** preferred language for the manufacturer/series name in order of priority */
    language: Array<string>;
}

/**
 * Plugin used to register additional (non-OFML) manufacturers.
 *  - Plugin category = `ManufacturerDatabase`
 */
export interface ManufacturerDatabase extends Plugin
{
    /**
     * Returns a list of additional manufacturers for the given session.
     * The ID of the manufacturer should be unique and should not conflict with the ID of an
     * OFML manufacturer. Conflicting/duplicate manufacturers will be ignored.
     * @param pSession The active EAIWS session.
     * @param pOptions Additional options.
     */
    getManufacturers(pSession: EaiwsSession, pOptions: GetManufacturersOptions): Promise<Array<Manufacturer>>;
}