import { EaiwsSession } from "@easterngraphics/wcf/modules/eaiws";
import * as project from "@easterngraphics/wcf/modules/eaiws/project";

import { Plugin } from "../Plugin";

export interface ProjectPickerOptions
{
    /** Custom title for the picker. */
    title?: string;

    /** If defined the project picker only lists projects with the given states. */
    projectStates?: Array<project.ProjectState>;

    /** If defined the project picker will load the project into the given session otherwise a new session will be created. */
    eaiwsSession?: EaiwsSession;

    /** Defines if and how opened projects should be locked. */
    projectLockingMode?: project.LockingMode;
}

export interface ProjectPickerResult
{
    /** The session with the loaded project. If null, the user canceled the picking process. */
    eaiwsSession: EaiwsSession | null;

    /** If true the user has only readonly access for the loaded project. */
    readonlyAccess?: boolean;
}

/**
 * The ProjectPickerPlugin allows the user to select/manage projects.
 * - Plugin category = `ProjectPicker`
 */
export interface ProjectPickerPlugin extends Plugin
{
    /**
     * Opens the project picker which enables the user to select and open a project.
     */
    pickProject(pOptions: ProjectPickerOptions): Promise<ProjectPickerResult>;
}
