const webpack = require('webpack');

module.exports = env => ({
    mode: process.env.NODE_ENV || "development",

    entry: {
        "plugin": ["./src/index.ts"]
    },

    target: ["web", "es2017"],

    output: {
        filename: "[name].js",
        path: env.distPath
    },

    // Enable sourcemaps for debugging webpack's output.
    devtool: process.env.NODE_ENV === "production" ? "nosources-source-map" : "source-map",

    stats: "errors-warnings",

    performance: {
        hints: false,
    },

    resolve: {
        // Add '.ts' and '.tsx' as resolvable extensions.
        extensions: [".ts", ".tsx", ".js", ".json"]
    },

    module: {
        rules: [
            // All files with a '.ts' or '.tsx' extension will be handled by 'awesome-typescript-loader'.
            { test: /\.tsx?$/, loader: "ts-loader", options: { configFile: "tsconfig.json", logLevel: "info" } },

            // All output '.js' files will have any sourcemaps re-processed by 'source-map-loader'.
            { enforce: "pre", test: /\.js$/, loader: "source-map-loader" },

            //enable support for embedded css
            { test: /\.css$/, use: ["style-loader", "css-loader"] }
        ]
    },

    plugins: [
        new webpack.DllReferencePlugin({
            manifest: __dirname + "/plugin-sdk/wbk-sharedlib/wbk-sharedlib-manifest.json"
        })
    ]
});